@@ -3,6 +3,7 @@ import typing
 from pathlib import Path
 
 import click
+import typing_extensions
 
 from . import models
 from . import postprocess as post
@@ -191,8 +192,9 @@ def run(
     spring: float,
     traction: float,
     fix_right_plane: bool,
-    coupling_type: typing.Literal[
+    coupling_type: typing_extensions.Literal[
         "fully_coupled_ORdmm_Land",
+        "fully_coupled_Tor_Land",
         "explicit_ORdmm_Land",
         "pureEP_ORdmm_Land",
     ],
@@ -236,7 +238,6 @@ def run_json(path):
 
 
 def main(config: typing.Optional[Config]):
-
     if config is None:
         config = Config()
 
