@@ -3,6 +3,7 @@ import typing
 from dataclasses import dataclass
 
 import dolfin
+import typing_extensions
 
 from . import utils
 
@@ -34,7 +35,10 @@ class Config:
     popu_factors_file: utils.PathLike = ""
     disease_state: str = "healthy"
     dt_mech: float = 1.0
-    mechanics_solve_strategy: typing.Literal["fixed", "adaptive"] = "adaptive"
+    mechanics_solve_strategy: typing_extensions.Literal[
+        "fixed",
+        "adaptive",
+    ] = "adaptive"
     # mechanics_ode_scheme: land_model.Scheme = land_model.Scheme.analytic
     ep_ode_scheme: str = "GRL1"
     ep_preconditioner: str = "sor"
@@ -43,8 +47,9 @@ class Config:
     mechanics_use_continuation: bool = False
     mechanics_use_custom_newton_solver: bool = False
     PCL: float = 1000
-    coupling_type: typing.Literal[
+    coupling_type: typing_extensions.Literal[
         "fully_coupled_ORdmm_Land",
+        "fully_coupled_Tor_Land",
         "explicit_ORdmm_Land",
         "pureEP_ORdmm_Land",
     ] = "fully_coupled_ORdmm_Land"
