@@ -1,6 +1,7 @@
 from . import em_model
 from . import explicit_ORdmm_Land
 from . import fully_coupled_ORdmm_Land
+from . import fully_coupled_Tor_Land
 from . import pureEP_ORdmm_Land
 
 
@@ -8,6 +9,7 @@ def list_coupling_types():
     return [
         "explicit_ORdmm_Land",
         "fully_coupled_ORdmm_Land",
+        "fully_coupled_Tor_Land",
         "pureEP_ORdmm_Land",
     ]
 
@@ -16,12 +18,14 @@ loggers = (
     explicit_ORdmm_Land.loggers
     + fully_coupled_ORdmm_Land.loggers
     + pureEP_ORdmm_Land.loggers
+    + fully_coupled_Tor_Land.loggers
 )
 
 
 __all__ = [
     "explicit_ORdmm_Land",
     "fully_coupled_ORdmm_Land",
+    "fully_coupled_Tor_Land",
     "em_model",
     "pureEP_ORdmm_Land",
     "loggers",
