@@ -1,6 +1,7 @@
 import json
 from pathlib import Path
 from typing import Dict
+from typing import Iterable
 from typing import List
 from typing import Optional
 from typing import Tuple
@@ -50,7 +51,6 @@ def extract_traces(
     reduction: str = "average",
     names: Optional[List[Tuple[str, str]]] = None,
 ) -> Dict[str, Union[np.ndarray, Dict[str, np.ndarray]]]:
-
     if loader.time_stamps is None:
         logger.warning("No data found in loader")
         return {}
@@ -88,7 +88,6 @@ def extract_traces(
 
 
 def plot_state_traces(results_file: utils.PathLike, reduction: str = "average"):
-
     results_file = Path(results_file)
     if not results_file.is_file():
         raise FileNotFoundError(f"File {results_file} does not exist")
@@ -156,7 +155,6 @@ def plot_state_traces(results_file: utils.PathLike, reduction: str = "average"):
 
     # If there is a residual.txt file: load and plot these results
     if loader.residual:
-
         # Back to initial dt and time points
         # dt = 0.05  # FIXME: Do we really want to hardcode in this value?
         # times_dt = np.arange(
@@ -245,7 +243,6 @@ def plot_state_traces(results_file: utils.PathLike, reduction: str = "average"):
 
 
 def make_xdmffiles(results_file, names=None):
-
     loader = DataLoader(results_file)
     outdir = Path(results_file).parent
 
@@ -332,7 +329,6 @@ def stats(y):
 
 
 def extract_last_beat(y, time, pacing, return_interval=False):
-
     allbeats = apf.Beats(y=y, t=time, pacing=pacing)
 
     try:
@@ -487,7 +483,6 @@ def json_serial(obj):
 
 
 def numpyfy(d):
-
     if isinstance(d, (list, tuple)):
         return np.array(d)
     if np.isscalar(d):
@@ -533,3 +528,24 @@ def save_popu_json(population_folder, num_models):
 
     print("Start analysis of single node results")
     get_biomarkers(results, population_folder, num_models)
+
+
+def activation_map(
+    voltage: Iterable[dolfin.Function],
+    time_stamps: Iterable[float],
+    V: dolfin.FunctionSpace,
+    threshold: float = 0.0,
+    t0: float = 0.0,
+) -> dolfin.Function:
+    activation_map = dolfin.Function(V)
+    activation_map.vector()[:] = t0 - 1
+
+    for t, v in zip(time_stamps, voltage):
+        dofs = np.logical_and(
+            v.vector()[:] >= threshold,
+            activation_map.vector()[:] < t0,
+        )
+
+        activation_map.vector()[np.where(dofs)[0]] = float(t)
+
+    return activation_map
