@@ -51,7 +51,12 @@ def dict_to_h5(data, h5name, h5group):
         else:
             group = h5file.create_group(h5group)
         for k, v in data.items():
-            group.create_dataset(k, data=v)
+            try:
+                group.create_dataset(k, data=v)
+            except OSError:
+                logger.warning(
+                    f"Unable to save key {k} with data {v} in {h5name}/{h5group}",
+                )
 
 
 def decode(x):
@@ -90,7 +95,6 @@ def check_file_exists(h5_filename, raise_on_false=True):
 
 
 def group_in_file(h5_filename, h5group):
-
     check_file_exists(h5_filename)
     exists = False
 
@@ -169,6 +173,8 @@ def load_state(
         from .models.fully_coupled_ORdmm_Land import EMCoupling  # type: ignore
     elif config.coupling_type == "pureEP_ORdmm_Land":
         from .models.pureEP_ORdmm_Land import EMCoupling  # type: ignore
+    elif config.coupling_type == "fully_coupled_Tor_Land":
+        from .models.fully_coupled_Tor_Land import EMCoupling  # type: ignore
     else:
         raise ValueError(f"Invalid coupling type: {config.coupling_type}")
 
